@@ -1,5 +1,7 @@
 package Minion::Backend::mysql;
 
+use 5.010;
+
 use Mojo::Base 'Minion::Backend';
 
 use Mojo::IOLoop;
@@ -9,7 +11,7 @@ use Sys::Hostname 'hostname';
 
 has 'mysql';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub dequeue {
   my ($self, $id, $wait, $options) = @_;
@@ -735,7 +737,7 @@ Minion::Backend::mysql
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -1151,7 +1153,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexander Nalobin Olaf Alders Zoffix Znet
+=for stopwords Alexander Nalobin Olaf Alders Paul Cochrane Zoffix Znet
 
 =over 4
 
@@ -1165,6 +1167,10 @@ Olaf Alders <olaf@wundersolutions.com>
 
 =item *
 
+Paul Cochrane <paul@liekut.de>
+
+=item *
+
 Zoffix Znet <cpan@zoffix.com>
 
 =back
